# Branch Registry

| Branch | Status | Parent | Purpose | Last Active |
|--------|--------|--------|---------|-------------|
| main | ACTIVE | — | Stable releases | 2026-03-15 |
| feature-streaming-intelligence | ACTIVE | main | ADR-105: Streaming Intelligence + Quality Gate | 2026-03-15 |
